@@ -2,6 +2,8 @@ from datetime import datetime
 import json
 import re
 import os
+
+import progressbar
 import requests
 import shutil
 import time
@@ -187,12 +189,12 @@ class FileTree(object):
         a = []
         b = []
         for f in files[:]:
-            if re.findall(r'^\d+', f) != []:
+            if re.findall(r'^\d+', f):
                 a.append(f)
             else:
                 b.append(f)
-        a = sorted(a, key = lambda f: int(re.findall(r'^\d+', f)[0]))
-        b = sorted(b, key = lambda f: f)
+        a = sorted(a, key=lambda f: int(re.findall(r'^\d+', f)[0]))
+        b = sorted(b, key=lambda f: f)
         return a+b
 
     def files(self):
@@ -205,7 +207,10 @@ class FileTree(object):
 
     def paths(self):
         arr = [t.root() for t in self.__paths]
-        # jprint(arr)
+        return self.__sortFiles(arr)
+
+    def paths_full(self):
+        arr = [t.root_full() for t in self.__paths]
         return self.__sortFiles(arr)
 
     def get_size(self):
@@ -225,6 +230,9 @@ class FileTree(object):
     def root(self):
         return self.__root_path.split('/')[-1]
 
+    def root_full(self):
+        return self.__root_path
+
     def obj(self):
         arr = []
         arr.extend(self.files())
